#
# spec file for package usbredir
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2011 Dominique Leuenberger, Amsterdam, The Netherlands.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           usbredir
Version:        0.14.0
Release:        1.5
Summary:        A protocol for redirecting USB traffic
License:        GPL-2.0-or-later AND LGPL-2.1-or-later
Group:          System/Libraries
URL:            https://www.spice-space.org/usbredir.html
Source:         https://www.spice-space.org/download/usbredir/%{name}-%{version}.tar.xz
Source1:        https://www.spice-space.org/download/usbredir/%{name}-%{version}.tar.xz.sig
Source99:       %{name}.keyring
BuildRequires:  gcc-c++
BuildRequires:  glib2-devel >= 2.44
BuildRequires:  meson >= 0.48
BuildRequires:  pkgconfig(libusb-1.0) >= 1.0.22
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
usbredir is a protocol for redirecting USB traffic from a single USB device,
to a different (virtual) machine than the one to which the USB device is
attached. See usb-redirection-protocol.md for the description / definition
of this protocol.

%package -n libusbredirhost1
Summary:        A protocol for redirecting USB traffic - Host-side library
Group:          System/Libraries

%description -n libusbredirhost1
usbredir is a protocol for redirecting USB traffic from a single USB device,
to a different (virtual) machine than the one to which the USB device is
attached. See usb-redirection-protocol.md for the description / definition
of this protocol.

%package -n libusbredirparser1
Summary:        A protocol for redirecting USB traffic - Client-side library
Group:          System/Libraries
Obsoletes:      libusbredirparser0 < %{version}
Provides:       libusbredirparser0 = %{version}

%description -n libusbredirparser1
usbredir is a protocol for redirecting USB traffic from a single USB device,
to a different (virtual) machine than the one to which the USB device is
attached. See usb-redirection-protocol.md for the description / definition
of this protocol.

%package devel
Summary:        A protocol for redirecting USB traffic - Development files
Group:          Development/Languages/C and C++
Requires:       libusbredirhost1 = %{version}
Requires:       libusbredirparser1 = %{version}

%description devel
usbredir is a protocol for redirecting USB traffic from a single USB device,
to a different (virtual) machine than the one to which the USB device is
attached. See usb-redirection-protocol.md for the description / definition
of this protocol.

%prep
%autosetup -n %{name}-%{version} -p1

%build
%meson
%meson_build

%install
%meson_install

%post -n libusbredirhost1 -p /sbin/ldconfig
%postun -n libusbredirhost1 -p /sbin/ldconfig
%post -n libusbredirparser1 -p /sbin/ldconfig
%postun -n libusbredirparser1 -p /sbin/ldconfig

%files
%defattr(-,root,root)
%doc ChangeLog.md README.md
%license COPYING
%{_bindir}/usbredirect
%{_mandir}/man1/usbredirect.1.gz

%files -n libusbredirhost1
%defattr(-, root, root)
%{_libdir}/libusbredirhost.so.*

%files -n libusbredirparser1
%defattr(-, root, root)
%{_libdir}/libusbredirparser.so.*

%files devel
%defattr(-, root, root)
%doc docs/multi-thread.md docs/usb-redirection-protocol.md
%{_includedir}/usbredirhost.h
%{_includedir}/usbredirfilter.h
%{_includedir}/usbredirparser.h
%{_includedir}/usbredirproto.h
%{_libdir}/libusbredirhost.so
%{_libdir}/libusbredirparser.so
%{_libdir}/pkgconfig/libusbredirhost.pc
%{_libdir}/pkgconfig/libusbredirparser-0.5.pc

%changelog
* Sun Mar 17 2024 Dirk Müller <dmueller@suse.com>
- update to 0.14.0:
  * usbredirect: Fix redirecting identical devices
  * usbredirect: Fix CPU tight loop when run as TCP server
  * usbredirect: Fix some minor memory leaks
  * usbredirect: Add documentation about bus-device option
  * usbredirtestclient: Fix build on MacOS 10.5
* Tue Aug  9 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 0.13.0:
  + Fix regression on unserialize data
  + Removes usbredirserver
  + Improved header length checks when unserialising data
  + Fix usage of command line argument in usbredirect
  + Fix small memory leak on usbredirect
- Drop 9426fdb1.patch and dffc41c3.patch: fixed upstream.
- Drop
  0001-Use-D_FORTIFY_SOURCE-instead-of-Wp-D_FORTIFY_SOURCE.patch:
  fixed upstream.
- Add keyring to validate source signature.
* Wed Jun  8 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Add upstream backported patches (boo#1199354):
  + 9426fdb1.patch: Check header length unserialising data.
  + dffc41c3.patch: usbredirect: fix leak on bad input.
* Tue Apr 12 2022 Martin Liška <mliska@suse.cz>
- Add 0001-Use-D_FORTIFY_SOURCE-instead-of-Wp-D_FORTIFY_SOURCE.patch
  that enables future switch to -D_FORTIFY_SOURCE=3
  (gl#spice/usbredir#60).
* Wed Jan  5 2022 Dominique Leuenberger <dimstar@opensuse.org>
- Drop unknown llvm-fuzz meson paramerter: meson 0.60 is strict and
  fails when unknown parameters are being passed.
* Mon Dec 20 2021 Dirk Müller <dmueller@suse.com>
- update to 0.12.0:
  * Implement dropping packets from isochronous devices
    when buffer is owned by usbredirparser library
  * Use packet size limit on deserialization
  * Fix possible bad state in deserialization logic
  * Fix possible memory leak in serialization logic
  * Fix (un)serialization with empty write buffers
  * Improvements to usbredirparserfuzz
* Tue Aug 24 2021 Michal Suchanek <msuchanek@suse.de>
- Update to version 0.11.0
  - Avoid use-after-free in serialization (CVE-2021-3700, bsc#1189491)
  - Add local directory to include search path for meson
  - Fix generated by meson libusbredirhost.pc
- Remove upstreamed patches
  - meson-Fix-include-directories-needed-to-build.patch
  - meson-Fix-pkgconfig-required-library-name-reference.patch
  - usbredir-CVE-2021-3700.patch
* Tue Aug 24 2021 ro@suse.de
- add patch usbredir-CVE-2021-3700.patch
  fix use-after-free in usbredirparser_serialize
  (CVE-2021-3700,bsc#1189491)
* Mon Apr  5 2021 Bruce Rogers <brogers@suse.com>
- Update to version 0.9.0
  + Changes noted in ChangeLog.md:
    !2 Add usbredirect tool with feature parity with usbredirserver
    !6 Add fuzzer for usbredirparser
    !12 Add MSI installer for usbredirect tool
    !11 Add meson build: autotool will be removed in a future release
    !5 Limit packet's length to 65 kB
    !4 Fix wrong up-cast when checking for package's length
    Require LLVM's compiler-rt (optional: for fuzzer)
    Require glib2 >= 2.44 (optional: for usbredirect)
    Deprecate usbredirserver in favor of usbredirect
  + Require libusb-1.0 >= 1.22 due to libusb_set_option() usage
  + Require meson >= 0.48 due to dictionary usage
  + Change docs to be in markdown format
  + add usbredir TCP client
  + add meson build support (which we now use to build package)
- Package the new usbredir TCP client: 'usbredirect'
- Fix meson include directory paths
  + meson-Fix-include-directories-needed-to-build.patch
- Fix pkgconfig data used in meson build
  + meson-Fix-pkgconfig-required-library-name-reference.patch
* Mon Sep 17 2018 Bruce Rogers <brogers@suse.com>
- Update to version 0.8.0
  + usbredirfilter:
  - Fix busy wait due endless recursion when interface_count is zero
  + usbredirhost:
  - Fix leak on error
  + usbredirserver:
  - Use 'busnum-devnum' instead of 'usbbus-usbaddr'
  - Add support for bind specific address -4 for ipv4, -6 for ipv6
  - Reject empty vendorid from command line
  - Enable TCP keepalive
* Tue Feb 16 2016 mkravec@suse.com
- Update to version 0.7.1
  + usbredirfilter:
  - force check to device which had all interfaces skipped. This fix a bug
    which allow a KVM device to be redirect when it should not
  + usbredirparser:
  - allow missing capabilities from source host when loading a USB
    redirection stream during a qemu migration
  + usbredirhost:
  - new callback to drop isoc packets when application's pending writes buffer
    size is too big; The threshold calculation aims at 10fps as worst case to
    give at least 150ms of continuous data to application.
* Wed Oct 15 2014 zaitor@opensuse.org
- Update to version 0.7:
  + usbredirproto:
  - The usb_redir_ep_info_header has been extended with a
    max_streams field, this is only send / received if both sides
    have usb_redir_cap_bulk_streams.
  - Change bulk_stream packet definitions to allow allocating/
    freeing streams on multiple endpoints in one go, technically
    this is a protocol change, but no-one has implemented
    usb_redir_cap_bulk_streams so far, so we can safely do this.
  - Add a USBREDIR_VERSION define so applications can test
    against which version they are building.
  + usbredirparser: Fix a bug causing parsing breakage when
    receiving a hello packet with 64 bit id capabiliy and another
    packet in succession so that they both got parsed in one
    usbredirparser_do_read call.
  + usbredirhost:
  - Use libusb_set_auto_detach_kernel_driver when available.
  - Add support for bulk streams, this only gets enabled with
    libusbx >= 1.0.19.
  - Stop iso / bulk streams on reset.
  - Make cancellation handeling more robust.
  - Reset device on release.
  + usbredirserver: Listen to both ipv4 and ipv6 addresses on ipv6
    capable systems.
* Sun Dec 23 2012 zaitor@opensuse.org
- Update to version 0.6:
  + usbredirproto:
  - add support for bulk packets with 32 bits length
  - add support for buffered bulk input
  + usbredirparser:
  - add support for bulk packets with 32 bits length
  - add support for buffered bulk input
  + usbredirhost:
  - add support for bulk packets with 32 bits length
  - queue multiple transfers for interrupt receiving
  - add support for buffered bulk input
  - only apply mult to max-packet-size for isoc high speed
    endpoints
  - add a do-not-reset device blacklist, populate it with
    1210:001c
- Changes from version 0.5.3:
  + usbredirparser:
  - add support for bulk packets longer then 65535 bytes
  + usbredirhost:
  - add support for bulk packets longer then 65535 bytes
* Mon Dec  3 2012 p.drouand@gmail.com
- Rename libusbredirparser0 to libusbredirparser1:
  The lib version has changed
* Mon Dec  3 2012 p.drouand@gmail.com
- Update to version 0.5.2:
  + usbredirparser:
  - rename libusbredirparser.pc to libusbredirparser-0.5.pc
    This should really have been done with the 0.5 release as API
    compatibility with previous releases was broken there!
* Mon Dec  3 2012 p.drouand@gmail.com
- Update to version 0.5.1:
  + usbredirparser:
  - usbredirparser_has_data_to_write now returns the write queue depth,
    instead of only 0 or 1
  + usbredirhost:
  - usbredirhost_has_data_to_write now returns the write queue depth,
    instead of only 0 or 1
  - when the write queue gets too large, drop isochronous input packets
* Mon Dec  3 2012 p.drouand@gmail.com
- Update to version 0.5:
  - Windows support
  - Add support for 64 bit packet ids
  - usbredirparser:
  - Add state serialization support
  - API and ABI changed to use 64 bit ids,
  - usbredirhost:
  - Remove bulk packets time out, this fixes various devices not working
  - Ack packet cancels immediately
  - Now supports 64 bits packet ids
  - Use libusb_error_name instead of logging raw error codes
  - usbredirfilter_check return -ENOENT rather then -EPERM if no rules match a
  device, this way the caller can differentiate between a deny caused by a
  matching rule, and one caused by there being no matching rules.
* Fri Apr 20 2012 joop.boonen@opensuse.org
- Update to version 0.4.3:
  + usbredirhost:
  - Don't crash on devices in unconfigured state
  - Restore original device configuration when releasing the device
  - Significantly speed up reset handling
  + usbredirserver:
  - Add a manpage
* Fri Mar  9 2012 dimstar@opensuse.org
- Update to version 0.4.2:
  + Add usb_redir_babble status code
  + usbredirparser:
  - extend the usb_redir_ep_info packet header with a
    max_packet_size field
  + usbredirhost:
  - Ensure we always re-attach kernel drivers on cleanup
  - Make set_config handling more robust
  - A set_config or a reset can cause us to loose access to the
    device
- Changes from version 0.4.1:
  + Brown paper bag release, fix a return without value in a non
    void function
- Changes from version 0.4:
  + Add usb_redir_filter_reject and usb_redir_filter_filter
    packets and an usb_redir_cap_filter capability flag
  + Add an usb_redir_device_disconnect_ack packet and an
    usb_redir_cap_device_disconnect_ack capability flag
  + usbredirparser:
  - Add an usbredirparser_have_peer_caps function
  + usbredirhost:
  - Allow re-using a host instance with multiple devices
  - Quite a few bugfixes
* Tue Jan 31 2012 dimstar@opensuse.org
- Update to version 0.3.3:
  + usbredirparser:
  - add usbredirfilter code, to help apps exclude certain devices
    from redirection.
  + usbredirhost:
  - add a usbredirhost_check_device_filter helper function.
- Changes from version 0.3.2:
  + Switched to automake/autoconf/libtool based make system
  + usbredirparser:
  - limited multi-thread safeness, see README.multi-thread
  - extend the device_connect packet header with a device_version
    field
  - Add a hello_func callback which gets called after receiving
    the hello packet from the other side. This can be used to
    determine when the caps from the other side have been
    received and it thus is safe to call
    usbredirparser_send_device_connect.
  + usbredirhost:
  - limited multi-thread safeness, see README.multi-thread
  - properly handle clear stalls send from the usbguest
  - try to keep our iso buffer size near the target size
  - implement usb_redir_cap_connect_device_version
- Call configure instead of exporting LDFLAGS and CPPFLAGS; this
  is now possible as upstream switched to auto*.
* Thu Nov 24 2011 dimstar@opensuse.org
- Initial package, version 0.3.1
